| Title: | Datasets for AQLT trainings |
|---|---|
| Description: | Package containing data for AQLT training courses. |
| Authors: | Alain Quartier-la-Tente [aut, cre] (ORCID: <https://orcid.org/0000-0001-7890-3857>) |
| Maintainer: | Alain Quartier-la-Tente <[email protected]> |
| License: | EUPL |
| Version: | 0.1.0 |
| Built: | 2026-05-18 21:28:35 UTC |
| Source: | https://github.com/AQLT/AQLTrainings |
Dataset containing monthly industrial production indices in manufacturing in the European Union (from sts_inpr_m dataset of Eurostat).
Data are based 100 in 2021 and are unadjusted (ipi_c_eu_nsa), i.e. neither seasonally adjusted nor calendar adjusted,
or seasonally and calendar adjusted (ipi_c_eu_sca).
ipi_c_eu_nsa ipi_c_eu_scaipi_c_eu_nsa ipi_c_eu_sca
A monthly ts object from January 2000 to December 2025 with 34 variables.
An object of class mts (inherits from ts, matrix, array) with 312 rows and 35 columns.
The dataset contains 34 time series corresponding to the following geographical area
| BE | Belgium |
| BG | Bulgaria |
| CZ | Czech Republic |
| DK | Denmark |
| DE | Germany (until 1990 former territory of the FRG) |
| EE | Estonia |
| IE | Ireland |
| EL | Greece |
| ES | Spain |
| FR | France |
| HR | Croatia |
| IT | Italy |
| CY | Cyprus |
| LV | Latvia |
| LT | Lithuania |
| LU | Luxembourg |
| HU | Hungary |
| MT | Malta |
| NL | Netherlands |
| AT | Austria |
| PL | Poland |
| PT | Portugal |
| RO | Romania |
| SI | Slovenia |
| SK | Slovakia |
| FI | Finland |
| SE | Sweden |
| UK | United Kingdom |
| NO | Norway |
| CH | Switzerland |
| ME | Montenegro |
| MK | Former Yugoslav Republic of Macedonia, the |
| RS | Serbia |
| TR | Turkey |
| BA | Bosnia and Herzegovina |
Eurostat, 'sts_inpr_m' database.
Dataset containing fictitious data for Macronia (fictitious country): monthly industrial production indices (IPI), Monthly Indicators of Economic Growth (MIEG) , quarterly national accounts (QNA) and annualy national acounts (ANA).
macroniamacronia
A list with ts objects
Eurostat, 'sts_inpr_m' database.
Function that allows importing series from Insee's Macroeconomic Database (BDM) using its idbank. A series' idbank can be found on the BDM website (https://www.bdm.insee.fr/bdm2/index). Also allows the use of quantile regressions.
read_bdm(idbank, ...)read_bdm(idbank, ...)
idbank |
a vector of one or more idbanks to download. |
... |
additional vectors of one or more idbanks to download. |
The function allows downloading time series from Insee's Macroeconomic Database (BDM) using their idbank. It leverages Insee's SDMX web service for this purpose (see http://www.bdm.insee.fr/bdm2/statique?page=sdmx for more information). It uses the rsdmx package to read the data and reshape2 for formatting. The idbanks passed as parameters must correspond to series that share the same periodicity. If one of the input idbanks is not found, the function will also return a warning message.
Returns an object of type ts or mts, depending on the number of input idbanks,
with the same frequency as the input series.
# To download the seasonally adjusted manufacturing IPI: 001654241 read_bdm("001654241") # To download the IPI for both manufacturing and agribusiness industries: read_bdm(c("001654241","001654289")) # or: read_bdm("001654241","001654289")# To download the seasonally adjusted manufacturing IPI: 001654241 read_bdm("001654241") # To download the IPI for both manufacturing and agribusiness industries: read_bdm(c("001654241","001654289")) # or: read_bdm("001654241","001654289")